from django.apps import AppConfig


class IchecDjangoCoreConfig(AppConfig):
    default_auto_field = "django.db.models.BigAutoField"
    name = "ichec_django_core"
    verbose_name = "ICHEC Django Core"
