# Generated by Django 5.2.3 on 2025-10-31 16:00

import functools
import ichec_django_core.models.utils
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("ichec_django_core", "0001_initial"),
    ]

    operations = [
        migrations.AlterField(
            model_name="member",
            name="profile",
            field=models.ImageField(
                null=True,
                upload_to=functools.partial(
                    ichec_django_core.models.utils.content_file_name,
                    *("profile",),
                    **{},
                ),
            ),
        ),
    ]
